#!/bin/bash
#############################################################################
# Purpose : Copy and apply Alfresco repo and/or share AMPs to overlay
# Author  : Thore P. C. Kragelund, Redpill Linpro
# Date    : 2014-09-30
# Package : alfresco-docker-utils-1.3.5
# Usage   : Run with name of project+instance and optional input paths
#############################################################################

function usage_error {
  echo -n "Usage: ${0##*/}"
  echo -n " <project>[:repo|share]"
  echo -n " [-f path_to_resource_files]"
  echo -n " [-t path_to_tmp_files]"
  echo -n " [-r]"
  echo
  exit 2
}

function deploy_amp {
  if [ ! -d "$RSRC_PATH/$INSTANCE-amps" ]; then
    echo "AMP resource directory '$RSRC_PATH/$INSTANCE-amps' not found. Exiting..."
    exit 2
  fi
  if [ -n "$TMP_PATH" ]; then
    $SCRIPT_PATH/sudock.sh cp -v $TMP_PATH/alfresco-$ALF_PRJ-$INSTANCE-*.amp $RSRC_PATH/$INSTANCE-amps
  fi
  $SCRIPT_PATH/sudock.sh cp -v $RSRC_PATH/$INSTANCE-amps/alfresco-$ALF_PRJ-$INSTANCE-*.amp $ALF_HOME/tomcat-$INSTANCE/amps
  $SCRIPT_PATH/sudock.sh $ALF_HOME/bin/apply_amps.sh $INSTANCE -q
  [ "$RESTART" == "true" ] && docker restart $ALF_PRJ-alf-$INSTANCE
}

SCRIPT_PATH="$(dirname $(readlink -f $0))"
RSRC_PATH="$SCRIPT_PATH/resources"
ALF_PRJ="${1%%:*}"
INSTANCE="${1##*:}"
RESTART="false"
shift
while getopts f:t:r OPTION; do
  case ${OPTION} in
    f)
      RSRC_PATH="$OPTARG"
      ;;
    t)
      TMP_PATH="$OPTARG"
      ;;
    r)
      RESTART="true"
      ;;
    \?)
      usage_error
      ;;
  esac
done

[ -z "$ALF_PRJ" ] && usage_error

ALF_HOME="/opt/alfresco/$ALF_PRJ"
INSTANCES="repo share"

if [ "$ALF_PRJ" == "$INSTANCE" ]; then
  for INSTANCE in $INSTANCES; do
    deploy_amp
  done
else
  deploy_amp
fi
