#!/bin/bash
#############################################################################
# Purpose : Utility script to setup Alfresco container overlay (local files)
# Author  : Thore P. C. Kragelund, Redpill Linpro
# Date    : 2014-06-13
# Package : alfresco-docker-utils-1.3.5
# Usage   : Run with name of project to init/clean and copy default files
#############################################################################

function usage_error {
  echo -n "Usage: ${0##*/}"
  echo -n " <project>[:repo|share]"
  echo -n " [-r alf_repo_port]"
  echo -n " [-R alf_repo_ssl_port]"
  echo -n " [-s alf_share_port]"
  echo -n " [-S alf_share_ssl_port]"
  echo -n " [-i alf_solr_port]"
  echo -n " [-I alf_solr_ssl_port]"
  echo -n " [-d alf_db_port]"
  echo -n " [-f path_to_resource_files]"
  echo
  exit 2
}

function install_repo_overlay {
  echo "Installing overlay $TC_REPO_HOME ..."
  mkdir -p $TC_REPO_HOME/webapps
  cp -v $RSRC_PATH/alfresco.war $TC_REPO_HOME/webapps
  if [ -f "$RSRC_PATH/_vti_bin.war" ]; then
    cp -v $RSRC_PATH/_vti_bin.war $TC_REPO_HOME/webapps
  fi
  if [ ! -d "$ALF_DATA/keystore" ]; then
    mkdir -p $ALF_DATA/keystore
    ./generate_keystores.sh $ALF_PRJ
  fi
  mkdir -p $TC_REPO_HOME/$ALF_LIC_LOC_REL
  cp -v $RSRC_PATH/*.lic $TC_REPO_HOME/$ALF_LIC_LOC_REL
  TC_REPO_CONF="$TC_REPO_HOME/shared/classes/alfresco-global.properties"
  cp -v $RSRC_PATH/alfresco-global.properties $TC_REPO_CONF
  sed -i "s|@@ALF_HOME@@|$CNT_ALF_HOME|" $TC_REPO_CONF
  sed -i "s|@@ALF_DATA@@|$CNT_ALF_DATA|" $TC_REPO_CONF
  sed -i "s|@@ALF_DB_HOST@@|$DOCKER_HOST|" $TC_REPO_CONF
  sed -i "s|@@ALF_DB_PORT@@|$ALF_DB_PORT|" $TC_REPO_CONF
  sed -i "s|@@ALF_REPO_HOST@@|$DOCKER_HOST|" $TC_REPO_CONF
  sed -i "s|@@ALF_REPO_PORT@@|$ALF_REPO_PORT|" $TC_REPO_CONF
  sed -i "s|@@ALF_REPO_SSL_PORT@@|$ALF_REPO_SSL_PORT|" $TC_REPO_CONF
  sed -i "s|@@ALF_SHARE_HOST@@|$DOCKER_HOST|" $TC_REPO_CONF
  sed -i "s|@@ALF_SHARE_PORT@@|$ALF_SHARE_PORT|" $TC_REPO_CONF
  sed -i "s|@@ALF_SHARE_SSL_PORT@@|$ALF_SHARE_PORT|" $TC_REPO_CONF
  sed -i "s|@@ALF_SOLR_HOST@@|$DOCKER_HOST|" $TC_REPO_CONF
  sed -i "s|@@ALF_SOLR_PORT@@|$ALF_SOLR_PORT|" $TC_REPO_CONF
  sed -i "s|@@ALF_SOLR_SSL_PORT@@|$ALF_SOLR_SSL_PORT|" $TC_REPO_CONF
  sed -i "s|@@ALF_LIC_LOC@@|$CNT_TC_HOME/$ALF_LIC_LOC_REL|" $TC_REPO_CONF
  mkdir $TC_REPO_HOME/amps
  if [ -d "$RSRC_PATH/repo-amps" ]; then
    cp -v $RSRC_PATH/repo-amps/*.amp $TC_REPO_HOME/amps
    $ALF_HOME/bin/apply_amps.sh repo -q
  fi
}

function install_share_overlay {
  echo "Installing overlay $TC_SHARE_HOME ..."
  mkdir -p $TC_SHARE_HOME/webapps
  cp -v $RSRC_PATH/share.war $TC_SHARE_HOME/webapps
  mkdir -p $TC_SHARE_HOME/shared/classes/alfresco/web-extension
  TC_SHARE_CONF="$TC_SHARE_HOME/shared/classes/alfresco/web-extension/share-config-custom.xml"
  cp -v $RSRC_PATH/share-config-custom.xml $TC_SHARE_CONF
  sed -i "s|@@ALF_REPO_HOST@@|$DOCKER_HOST|" $TC_SHARE_CONF
  sed -i "s|@@ALF_REPO_PORT@@|$ALF_REPO_PORT|" $TC_SHARE_CONF
  mkdir $TC_SHARE_HOME/amps
  if [ -d "$RSRC_PATH/share-amps" ]; then
    cp -v $RSRC_PATH/share-amps/*.amp $TC_SHARE_HOME/amps
    $ALF_HOME/bin/apply_amps.sh share -q
  fi
}

function install_solr_overlay {
  echo "Installing overlay $TC_SOLR_HOME ..."
  mkdir -p $TC_SOLR_HOME/webapps
  cp -v $RSRC_PATH/solr4.war $TC_SOLR_HOME/webapps/solr.war
}

ALF_DB_PORT="5432"
ALF_REPO_PORT="8080"
ALF_SHARE_PORT="8081"
ALF_SOLR_PORT="8082"
ALF_REPO_SSL_PORT="8443"
ALF_SHARE_SSL_PORT="8444"
ALF_SOLR_SSL_PORT="8445"
SCRIPT_PATH="$(dirname $(readlink -f $0))"
RSRC_PATH="$SCRIPT_PATH/resources"
ALF_PRJ="${1%%:*}"
INSTANCE="${1##*:}"
shift
while getopts r:R:s:S:i:I:d:f: OPTION; do
  case ${OPTION} in
    r)
      ALF_REPO_PORT="$OPTARG"
      ;;
    R)
      ALF_REPO_SSL_PORT="$OPTARG"
      ;;
    s)
      ALF_SHARE_PORT="$OPTARG"
      ;;
    S)
      ALF_SHARE_SSL_PORT="$OPTARG"
      ;;
    i)
      ALF_SOLR_PORT="$OPTARG"
      ;;
    I)
      ALF_SOLR_SSL_PORT="$OPTARG"
      ;;
    d)
      ALF_DB_PORT="$OPTARG"
      ;;
    f)
      RSRC_PATH="$OPTARG"
      ;;
    \?)
      usage_error
      ;;
  esac
done

[ -z "$ALF_PRJ" ] && usage_error

ALF_HOME="/opt/alfresco/$ALF_PRJ"
CNT_ALF_HOME="/opt/alfresco"
ALF_DATA="$ALF_HOME/alf_data"
CNT_ALF_DATA="$CNT_ALF_HOME/alf_data"
TC_REPO_HOME="$ALF_HOME/tomcat-repo"
TC_SHARE_HOME="$ALF_HOME/tomcat-share"
TC_SOLR_HOME="$ALF_HOME/tomcat-solr"
CNT_TC_HOME="/var/lib/tomcat7"
DOCKER_HOST="172.17.42.1"
ALF_LIC_LOC_REL="shared/classes/alfresco/extension/license"

if [ "$ALF_PRJ" == "$INSTANCE" ]; then
  [ -d "$ALF_HOME" ] && mv -v $ALF_HOME $ALF_HOME.$(date +%Y%m%d%H%M%S)
  mkdir -p $ALF_HOME/bin
  cp -v $RSRC_PATH/apply_amps.sh $RSRC_PATH/alfresco-mmt.jar $ALF_HOME/bin
  install_repo_overlay
  install_share_overlay
  install_solr_overlay
else
  case $INSTANCE in
  'repo')
    [ -d "$TC_REPO_HOME" ] && mv -v $TC_REPO_HOME $TC_REPO_HOME.$(date +%Y%m%d%H%M%S)
    install_repo_overlay
    ;;
  'share')
    [ -d "$TC_SHARE_HOME" ] && mv -v $TC_SHARE_HOME $TC_SHARE_HOME.$(date +%Y%m%d%H%M%S)
    install_share_overlay
    ;;
  'solr')
    [ -d "$TC_SOLR_HOME" ] && mv -v $TC_SOLR_HOME $TC_SOLR_HOME.$(date +%Y%m%d%H%M%S)
    install_solr_overlay
    ;;
  *)
    echo "Unknown instance '$INSTANCE'."
    exit 2
  esac
fi