#!/bin/bash
#############################################################################
# Purpose : Partial or total reset of the Alfresco Docker environment
# Author  : Thore P. C. Kragelund, Redpill Linpro
# Date    : 2014-09-18
# Package : alfresco-docker-utils-1.3.5
# Usage   : Run with project name and optional container names
#############################################################################

function usage_error {
  echo "Usage: ${0##*/} <project_name> [container_names]"
  exit 2
}

PRJ_NAME="$1"
[ -z "$PRJ_NAME" ] && usage_error

ALF_DB_PORT="5432"
SCRIPT_PATH="$(dirname $(readlink -f $0))"
RSRC_PATH="$SCRIPT_PATH/resources"
ALF_DB_BACKUP="$RSRC_PATH/$PRJ_NAME-db.backup"
CNT_NAMES="logserver log-ui alf-db alf-repo alf-share alf-solr"
if [ $# -gt 1 ]; then
  CNT_NAMES="${@:2}"
fi

echo "Destroying existing containers ..."
for CNT_NAME in $CNT_NAMES; do
  CNT_NAME="${CNT_NAME%%:*}"
  docker stop $PRJ_NAME-$CNT_NAME
  docker rm $PRJ_NAME-$CNT_NAME
done

if [ $# -eq 1 ]; then
  echo "Re-installing complete overlay ..."
  $SCRIPT_PATH/sudock.sh $SCRIPT_PATH/alf_overlay_install.sh $PRJ_NAME
  ALF_DB_INIT="true"
else
  if [ -n "$(echo $CNT_NAMES | grep alf-db)" ]; then
    ALF_DB_INIT="true"
  fi
  if [ -n "$(echo $CNT_NAMES | grep alf-repo)" ]; then
    echo "Re-installing repo overlay ..."
    $SCRIPT_PATH/sudock.sh $SCRIPT_PATH/alf_overlay_install.sh $PRJ_NAME:repo
  fi
  if [ -n "$(echo $CNT_NAMES | grep alf-share)" ]; then
    echo "Re-installing share overlay ..."
    $SCRIPT_PATH/sudock.sh $SCRIPT_PATH/alf_overlay_install.sh $PRJ_NAME:share
  fi
  if [ -n "$(echo $CNT_NAMES | grep alf-solr)" ]; then
    echo "Re-installing solr overlay ..."
    $SCRIPT_PATH/sudock.sh $SCRIPT_PATH/alf_overlay_install.sh $PRJ_NAME:solr
  fi
fi

echo "Creating new containers ..."
for CNT_NAME in $CNT_NAMES; do
  CNT_CMD_OPTS="${CNT_NAME##*:}"
  CNT_NAME="${CNT_NAME%%:*}"
  CNT_RUN_CMD="$SCRIPT_PATH/alf_docker_run.sh $PRJ_NAME $CNT_NAME -d"
  if [ "$CNT_CMD_OPTS" != "$CNT_NAME" ]; then
    if [ "$CNT_NAME" == "alf-db" ]; then
      ALF_DB_PORT="$CNT_CMD_OPTS"
    else
      CNT_RUN_CMD="$CNT_RUN_CMD -o $CNT_CMD_OPTS"
    fi
  fi
  $CNT_RUN_CMD
done

if [ "$ALF_DB_INIT" == "true" -a -f "$ALF_DB_BACKUP" ]; then
  echo "Restoring DB from '$ALF_DB_BACKUP' ..."
  DB_CMD="/usr/bin/pg_restore"
  DB_CMD="$DB_CMD --host localhost --port $ALF_DB_PORT"
  DB_CMD="$DB_CMD --dbname alfresco --username alfresco --no-password"
  DB_CMD="$DB_CMD --verbose $ALF_DB_BACKUP"
  sleep 3 # just to be sure db is up and running
  $DB_CMD
fi
