#!/bin/bash
#############################################################################
# Purpose : Utility script to run apply Alfresco AMPs
# Author  : Thore P. C. Kragelund, Redpill Linpro
# Date    : 2014-07-10
# Usage   : Run with Alfresco Tomcat instance name
#############################################################################

function usage_error {
  echo "Usage: ${0##*/} <repo|share> [-q]"
  exit 2
}

SCRIPT_PATH="$(dirname $(readlink -f $0))"
ALF_HOME="${SCRIPT_PATH%/*}"
ALF_TC_INSTANCE="$1"

case $ALF_TC_INSTANCE in
'repo')
  TARGET_APP="alfresco"
  ;;
'share')
  TARGET_APP="share"
  ;;
*)
  usage_error
esac

shift

QUIET="false"
while getopts q OPTION; do
  case ${OPTION} in
    q)
      QUIET="true"
      ;;
    \?)
      usage_error
      ;;
  esac
done

CATALINA_HOME="$ALF_HOME/tomcat-$ALF_TC_INSTANCE"
if [ ! -d "$CATALINA_HOME" ]; then
  echo "Could not locate directory $CATALINA_HOME. Exiting .."
  exit 1
fi

if [ "$QUIET" == "false" ]; then
  echo -n "Apply AMPs from $CATALINA_HOME/amps on $CATALINA_HOME/webapps/$TARGET_APP.war (Y/n)? "
  read RESP
fi
if [ "$RESP" != "n" ]; then
  java -jar $ALF_HOME/bin/alfresco-mmt.jar install $CATALINA_HOME/amps $CATALINA_HOME/webapps/$TARGET_APP.war -directory -force
  if [ $? -eq 0 ]; then
    for AMP in $CATALINA_HOME/amps/*.amp; do
      mv $AMP $AMP.$(date +%Y%m%d%H%M%S)
    done
  fi
  java -jar $ALF_HOME/bin/alfresco-mmt.jar list $CATALINA_HOME/webapps/$TARGET_APP.war
  chmod +r $CATALINA_HOME/webapps/$TARGET_APP.war
fi

if [ "$QUIET" == "false" ]; then
  echo -n "Remove existing application $CATALINA_HOME/webapps/$TARGET_APP (Y/n)? "
  read RESP
fi
if [ "$RESP" != "n" ]; then
  rm -Rf $CATALINA_HOME/webapps/$TARGET_APP
fi

